@@ -16,31 +16,34 @@ import org.gnu.glib.Handle;
 /**
  */
 public class ObjectFactory extends GObject {
-    
+
     public ObjectFactory(Handle handle) {
         super(handle);
     }
-    
+
     public AtkObject createAccessible(GObject object) {
-        return 
-            AtkObject.
-            getAtkObjectFromHandle( 
-                atk_object_factory_create_accessible(getHandle(), 
-                                                     object.getHandle()) );
+        return AtkObject
+                .getAtkObjectFromHandle(atk_object_factory_create_accessible(
+                        getHandle(), object.getHandle()));
     }
-    
+
     public void invalidate() {
         atk_object_factory_invalidate(getHandle());
     }
-    
+
     public Type getAccessibleType() {
-        return new Type(atk_object_factory_get_accessible_type(getHandle())); 
+        return new Type(atk_object_factory_get_accessible_type(getHandle()));
     }
 
     native static final protected int atk_object_factory_get_type();
-    native static final protected Handle atk_object_factory_create_accessible(Handle factory, Handle object);
-    native static final protected void atk_object_factory_invalidate(Handle factory);
-    native static final protected int atk_object_factory_get_accessible_type(Handle factory);
 
+    native static final protected Handle atk_object_factory_create_accessible(
+            Handle factory, Handle object);
+
+    native static final protected void atk_object_factory_invalidate(
+            Handle factory);
+
+    native static final protected int atk_object_factory_get_accessible_type(
+            Handle factory);
 
 }
