@@ -127,20 +127,36 @@ public class Calendar extends Widget {
 
     /**
      * Gets the selected date from a Calendar.
+     * <p>
+     * <i>Historical note: getDate() used to return java.util.Calendar. This
+     * caused some class library implementations to fault in their entire
+     * TimeZone subsystems which led to a very deep bug on some architectures.
+     * This method was therefore changed as of libgtk-java 2.10 to the int[3]
+     * implementation here.</i>
+     * </p>
      * 
-     * @return A Calendar object that represents the date selected in the
-     *         widget.
+     * @return a three wide array of integers: the array at [0] is the year (4
+     *         digits), the array at [1] is the month (range from 1-12), and the
+     *         array at [2] is the numeric day (range from 1-{28,29,30,31}).
+     * @since 2.10
      */
-    public java.util.Calendar getDate() {
-        int[] year = new int[1];
-        int[] month = new int[1];
-        int[] day = new int[1];
-        Calendar.gtk_calendar_get_date(getHandle(), year, month, day);
-        java.util.Calendar cal = java.util.Calendar.getInstance();
-        cal.set(java.util.Calendar.YEAR, year[0]);
-        cal.set(java.util.Calendar.MONTH, month[0]);
-        cal.set(java.util.Calendar.DAY_OF_MONTH, day[0]);
-        return cal;
+    public int[] getDate() {
+        int[] in = new int[3];
+        int[] out = new int[3];
+
+        Calendar.gtk_calendar_get_date(getHandle(), in);
+
+        // necessary to use intermediate variables otherwise you can get memory
+        // problems.
+        int year = in[0];
+        int month = in[1] + 1;
+        int day = in[2];
+
+        out[0] = year;
+        out[1] = month;
+        out[2] = day;
+
+        return out;
     }
 
     /**
@@ -331,8 +347,8 @@ public class Calendar extends Widget {
     native static final protected int gtk_calendar_get_display_options(
             Handle calendar);
 
-    native static final protected void gtk_calendar_get_date(Handle calendar,
-            int[] year, int[] month, int[] day);
+    native static final private void gtk_calendar_get_date(Handle calendar,
+            int[] triple);
 
     native static final protected void gtk_calendar_freeze(Handle calendar);
 
