@@ -14,9 +14,9 @@ import java.util.HashMap;
 import java.util.List;
 
 import org.gnu.gdk.Pixbuf;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 import org.gnu.glib.Value;
-import org.gnu.glib.Handle;
 
 /**
  * The ListStore is the gtk Model used for constructing Lists and tables to be
@@ -507,9 +507,9 @@ public class ListStore extends TreeModel implements TreeSortable,
      *            that dataBlock, as set in the constructor.
      */
     public void setValue(TreeIter iter, DataColumnPixbuf dataBlock,
-            org.gnu.gdk.Pixbuf value) {
-        Value val = new Value(Type.PIXBUF());
-        val.setPixbuf(value);
+            Pixbuf value) {
+        Value val = new Value(Type.OBJECT());
+        val.setJavaObject(value);
         gtk_list_store_set_value(getHandle(), iter.getHandle(), dataBlock
                 .getColumn(), val.getHandle());
     }
