@@ -22,17 +22,18 @@ import org.gnu.gtk.Widget;
  * @deprecated Use {@link DragOriginListener} instead.
  */
 public interface DragSourceListener {
-	
-	public void dragBegin(Widget widget, DragContext dc);
-	
-	public void dragMotion(Widget widget, DragContext dc, int x, int y);
-	
-	public void getDragData(Widget widget, DragContext dc, SelectionData sd, int info);
-	
-	public void deleteDragData(Widget widget, DragContext dc);
-	
-	public void dragDrop(Widget widget, DragContext dc, int x, int y);
-	
-	public void dragEnd(Widget widget, DragContext dc);
+
+    public void dragBegin(Widget widget, DragContext dc);
+
+    public void dragMotion(Widget widget, DragContext dc, int x, int y);
+
+    public void getDragData(Widget widget, DragContext dc, SelectionData sd,
+            int info);
+
+    public void deleteDragData(Widget widget, DragContext dc);
+
+    public void dragDrop(Widget widget, DragContext dc, int x, int y);
+
+    public void dragEnd(Widget widget, DragContext dc);
 
 }
