@@ -15,16 +15,14 @@ import org.gnu.glib.Handle;
  * The PangoAttrFloat structure is used to represent attributes with a float or
  * double value.
  */
-public class AttrFloat extends Attribute 
-{
-	/**
-	 * Returns the value
-	 */ 
-	public double getValue(){
-		return getValue(getHandle());
-	}
+public class AttrFloat extends Attribute {
+    /**
+     * Returns the value
+     */
+    public double getValue() {
+        return getValue(getHandle());
+    }
 
-    native static final protected double getValue (Handle obj);
+    native static final protected double getValue(Handle obj);
 
 }
-
